==> javie-0.3.0-src.tar.gz: javie-0.3.0-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/AbstractLayer.java <==
/*
 * Copyright (c) 2009 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core;

import net.arnx.jsonic.JSONHint;
import ch.kuramo.javie.api.Time;

public abstract class AbstractLayer implements Layer {

	private static final Time TIME0 = Time.fromFrameNumber(0, FrameDuration.FPS_29_97);


	private String _id;

	private String _parentId;

	private Layer _parent;

	private String _name;

	private boolean _shy;

	private Time _startTime;

	private Time _inPoint;

	private Time _outPoint;

	private double _rate;


	public AbstractLayer() {
		super();
	}

	protected void initialize(String name) {
		_id = Util.randomId();
		_name = name;

		_startTime = TIME0;
		_inPoint = TIME0;
		_outPoint = TIME0;
		_rate = 1.0;
	}

	public String getId() {
		return _id;
	}

	public void setId(String id) {
		_id = id;
	}

	public String getParentId() {
		return _parentId;
	}

	public void setParentId(String parentId) {
		_parentId = parentId;
	}

	@JSONHint(ignore=true)
	public Layer getParent() {
		return _parent;
	}

	@JSONHint(ignore=true)
	public void setParent(Layer parent) {
		_parentId = (parent != null) ? parent.getId() : null;
		_parent = parent;
	}

	public String getName() {
		return _name;
	}

	public void setName(String name) {
		_name = name;
	}

	public boolean isShy() {
		return _shy;
	}

	public void setShy(boolean shy) {
		_shy = shy;
	}

	public Time getStartTime() {
		return _startTime;
	}

	public void setStartTime(Time startTime) {
		_startTime = startTime;
	}

	public Time getInPoint() {
		return _inPoint;
	}

	public void setInPoint(Time inPoint) {
		_inPoint = inPoint;
	}

	public Time getOutPoint() {
		return _outPoint;
	}

	public void setOutPoint(Time outPoint) {
		_outPoint = outPoint;
	}

	public double getRate() {
		return _rate;
	}

	public void setRate(double rate) {
		_rate = rate;
	}

	public void afterDecode(Project p, LayerComposition c) throws ProjectDecodeException {
		if (_parentId != null) {
			_parent = c.getLayer(_parentId);
			if (_parent == null) {
				throw new ProjectDecodeException(
						"no such parent layer found: id=" + _parentId);
			}
		}
	}

	public void prepareExpression(ExpressionScope scope) {
		scope.setThis(this);
	}

	public class LayerExpressionElement {

		protected final RenderContext renderContext;

		public LayerExpressionElement(RenderContext renderContext) {
			this.renderContext = renderContext;
		}

		protected <T> T elem(Expressionee exprnee) {
			return renderContext.getExpressionElement(exprnee);
		}

		public LayerExpressionElement getThisLayer() {
			return this;
		}

		public double getStartTime()	{ return _startTime.toSecond(); }
		public double getInPoint()		{ return _inPoint.toSecond(); }
		public double getOutPoint()		{ return _outPoint.toSecond(); }
		public double getRate()			{ return _rate; }
	}

}

==> javie-0.3.1-src.tar.gz: javie-0.3.1-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/AbstractLayer.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core;

import net.arnx.jsonic.JSONHint;
import ch.kuramo.javie.api.Time;

public abstract class AbstractLayer implements Layer {

	private String _id;

	private String _parentId;

	private Layer _parent;

	private String _name = "名称未設定レイヤー";

	private boolean _shy;

	private Time _startTime;

	private Time _inPoint;

	private Time _outPoint;

	private double _rate = 1.0;


	public AbstractLayer() {
		super();
	}

	public void initialize() {
		_id = Util.randomId();
	}

	public String getId() {
		return _id;
	}

	public void setId(String id) {
		_id = id;
	}

	public String getParentId() {
		return _parentId;
	}

	public void setParentId(String parentId) {
		_parentId = parentId;
	}

	@JSONHint(ignore=true)
	public Layer getParent() {
		return _parent;
	}

	@JSONHint(ignore=true)
	public void setParent(Layer parent) {
		_parentId = (parent != null) ? parent.getId() : null;
		_parent = parent;
	}

	public String getName() {
		return _name;
	}

	public void setName(String name) {
		_name = name;
	}

	public boolean isShy() {
		return _shy;
	}

	public void setShy(boolean shy) {
		_shy = shy;
	}

	public Time getStartTime() {
		return _startTime;
	}

	public void setStartTime(Time startTime) {
		_startTime = startTime;
	}

	public Time getInPoint() {
		return _inPoint;
	}

	public void setInPoint(Time inPoint) {
		_inPoint = inPoint;
	}

	public Time getOutPoint() {
		return _outPoint;
	}

	public void setOutPoint(Time outPoint) {
		_outPoint = outPoint;
	}

	public double getRate() {
		return _rate;
	}

	public void setRate(double rate) {
		_rate = rate;
	}

	public void afterDecode(Project p, LayerComposition c) throws ProjectDecodeException {
		if (_parentId != null) {
			_parent = c.getLayer(_parentId);
			if (_parent == null) {
				throw new ProjectDecodeException(
						"no such parent layer found: id=" + _parentId);
			}
		}
	}

	public void prepareExpression(ExpressionScope scope) {
		scope.setThis(this);
	}

	public class LayerExpressionElement {

		protected final RenderContext renderContext;

		public LayerExpressionElement(RenderContext renderContext) {
			this.renderContext = renderContext;
		}

		protected <T> T elem(Expressionee exprnee) {
			return renderContext.getExpressionElement(exprnee);
		}

		public LayerExpressionElement getThisLayer() {
			return this;
		}

		public double getStartTime()	{ return _startTime.toSecond(); }
		public double getInPoint()		{ return _inPoint.toSecond(); }
		public double getOutPoint()		{ return _outPoint.toSecond(); }
		public double getRate()			{ return _rate; }
	}

}
